Name: blitz
Version: 0.10
Release: 9%{?dist}
Summary: C++ class library for matrix scientific computing

Group: Development/Libraries
License: LGPLv3+ or BSD or Artistic 2.0


URL: http://sourceforge.net/projects/blitz
Source0: http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
# Modifications of the Fedora package are listed here:
# * Arch dependent hader moved to lib/blitz/include
#   https://sourceforge.net/tracker/?func=detail&aid=3534421&group_id=63961&atid=505791
Source1: README.fedora
# Fails to compile with gcc 4.7
# https://sourceforge.net/tracker/?func=detail&atid=505791&aid=3534421&group_id=63961
Patch0: blitz-gcc47.patch

BuildRequires: gcc-gfortran doxygen texinfo graphviz
Requires(post): /sbin/install-info /sbin/ldconfig
Requires(preun): /sbin/install-info /sbin/ldconfig

%description
Blitz++ is a C++ class library for scientific computing which provides 
performance on par with Fortran 77/90. It uses template techniques to achieve 
high performance. Blitz++ provides dense arrays and vectors, random number 
generators, and small vectors

%package devel
Summary: Libraries, includes, etc. used to develop an application with %{name}
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig
%description devel
These are the header files and libraries needed to develop a %{name}
application

%package doc
Summary: The Blitz html docs
Group: Documentation
BuildArch: noarch

%description doc
HTML documentation files for the Blitz Library

%prep
%setup -q
%patch0 -p1
cp %SOURCE1 .

%build
%configure --enable-shared --disable-static --disable-cxx-flags-preset \
    --enable-64bit --enable-fortran \
    --disable-fortran-flags-preset 

make %{?_smp_mflags}
make info
make html
make pdf

# blitz.pc is created directly by configure
# I use sed to add %%libdir/blitz to the include directories of the library
# so that different bzconfig.h can be installed for different archs
# 
# The problem is reported here
# https://sourceforge.net/tracker/?func=detail&aid=2273091&group_id=63961&atid=505791
%{__sed} -i -e "s/Cflags: -I\${includedir}/Cflags: -I\${includedir} -I\${libdir}\/blitz\/include/" blitz.pc

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} install
make DESTDIR=%{buildroot} install-info

mkdir -p %{buildroot}%{_libdir}/blitz/include/blitz
mv %{buildroot}%{_includedir}/blitz/gnu %{buildroot}%{_libdir}/blitz/include/blitz

# Put in doc only the source code
rm -rf examples/.deps
rm -rf examples/Makefile*

%check
make %{?_smp_mflags} check-testsuite

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post devel
/sbin/install-info %{_infodir}/%{name}.info %{_infodir}/dir || :

%preun devel
if [ $1 = 0 ]; then
    /sbin/install-info --delete %{_infodir}/%{name}.info %{_infodir}/dir || :
fi

%files
%doc AUTHORS LEGAL COPYRIGHT COPYING COPYING.LESSER README LICENSE README.fedora
%{_libdir}/*so.*

%files devel
%doc examples
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_libdir}/blitz
%{_includedir}/*
%{_infodir}/*
%exclude %{_libdir}/*.la
%exclude %{_infodir}/dir

%files doc
%doc COPYRIGHT COPYING COPYING.LESSER README LICENSE
%doc doc/blitz.pdf
%doc doc/blitz.html
%doc examples

%changelog
* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 0.10-8
- Rebuilt for GCC 5 C++11 ABI change

* Fri Aug 15 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jul 06 2012 Sergio Pascual <sergiopr at fedoraproject.org> - 0.10-2
- Licensing updated: LGPLv3+ or BSD os Artistic 2.0

* Sun Jul 01 2012 Sergio Pascual <sergiopr at fedoraproject.org> - 0.10-1
- New upstream source 

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Dec 22 2009 Sergio Pascual <sergiopr at fedoraproject.org> - 0.9-13
- Using pregenerated documentation

* Sun Jul 26 2009 Sergio Pascual <sergiopr at fedoraproject.org> - 0.9-12
- Noarch doc subpackage

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu May  7 2009 Ville Skyttä <ville.skytta at iki.fi> - 0.9-10
- Build with $RPM_OPT_FLAGS.
- Disable autotools dependency tracking during build for cleaner build logs
  and possible slight build speedup.

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Jan 20 2009 Sergio Pascual <sergiopr at fedoraproject.org> - 0.9-8
- New patch (from upstream) to build with gcc4.3 

* Mon Mar 03 2008 Sergio Pascual <spr@astrax.fis.ucm.es> - 0.9-7
- Patch to build with gcc4.3

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.9-6
- Autorebuild for GCC 4.3

* Mon Jan 07 2008 Sergio Pascual <spr@astrax.fis.ucm.es> 0.9-5
- Excluding /usr/share/info/dir

* Sat Dec 22 2007 Sergio Pascual <sergiopr at fedoraproject.com> 0.9-4
- Removed conflicting Makefiles from examples (bug #340751)
- Arch dependent gnu/bzconfig.h moved to %%libdir/blitz/include/blitz/gnu

* Wed Oct 17 2007 Sergio Pascual <spr@astrax.fis.ucm.es> 0.9-3
- Removed macro in changelog

* Tue Oct 16 2007 Sergio Pascual <spr@astrax.fis.ucm.es> 0.9-2
- Excluding /usr/share/info/dir

* Wed Oct 03 2007 Sergio Pascual <spr@astrax.fis.ucm.es> 0.9-1
- Changed wrong date in changelog
- Changed license to gplv2 (some .h files haven't got the license text)
- Changed _datadir/info/* to _infodir/%%{name}*

* Thu Oct 02 2007 Sergio Pascual <spr@astrax.fis.ucm.es> 0.9-0.2
- Adding requires pkgconfig
- Changed license tag
- Removing requires(pre,un)

* Thu May 03 2007 Sergio Pascual <spr@astrax.fis.ucm.es> 0.9-0.1
- Initial RPM file
